import c4d, os, sys
from c4d import gui, plugins, bitmaps



# Testing ids 1000001 - 1000010
# be sure to use a unique ID obtained from www.plugincafe.com
__plugin_id__ = 1028671
__version__ = "1.0"
__plugin_title__ = "TexPath"

# SETTINGS
DW = 600            # Document Width
DH = 50             # Document Height


# Dialog Constants
TAB_ID1=100
GROUP_ID1=1000
TEX_PATHS=1001
TEX_PATH=1002
BTN_OPEN=1003

GROUP_ID2=2000
TEX_EXISTS=2001

GROUP_ID3=3000
BTN_SET=3001


# String shown in status bar
HELP_TEXT = "TexPath"


############################################################
# Checks Path and changes Layout
############################################################
def checkPath(path, geDialog):
    if os.path.exists(path) :
        geDialog.Enable(BTN_SET, True)
        geDialog.SetString(TEX_EXISTS, "Path exists - you can now change your texture path")
        geDialog.SetDefaultColor(TEX_EXISTS, c4d.COLOR_TEXT, c4d.Vector(0, 50, 0))   
    else:
        geDialog.Enable(BTN_SET, False) 
        geDialog.SetString(TEX_EXISTS, "Path doesn't exist - please enter a valid path")
        geDialog.SetDefaultColor(TEX_EXISTS, c4d.COLOR_TEXT, c4d.Vector(200, 0, 0))   

############################################################
# recursive function where we do stuff to the shaders
############################################################
def shadertree(shader,path):
    # Loop through the BaseList
    while(shader):         

        # This is where you do stuff
        # If it's a bitmap, we'll look at the filename

        if shader.GetType() == c4d.Xbitmap:
                   
            filename = shader[c4d.BITMAPSHADER_FILENAME]  
                  
            
            # for instance we can set the filename to just the file part
            filename = os.path.basename(filename)
            shader[c4d.BITMAPSHADER_FILENAME] = path+"\\"+filename
         
        # Check for child shaders & recurse
        if shader.GetDown(): shadertree(shader.GetDown(), path)
        # Get the Next Shader
        shader = shader.GetNext() 
         
############################################################
# replaceTexturepath
############################################################
def replaceTexturepath(path):
    # Get the first material
    mat = doc.GetFirstMaterial()
    # Loop through materials
    while(mat):       
        # Get the first shader
        # Note - this is a 4D list - you've gotta GetDown
        shd = mat.GetFirstShader()
        # Use our recursive function to parse the shader tree
        shadertree(shd, path)
        #print shd
        # Get the Next material
        mat = mat.GetNext()        
        
        
class MainDialog(gui.GeDialog):
    def CreateLayout(self):
        #creat the layout of the dialog  
        self.SetTitle("TexPath") 
        
        self.TabGroupBegin(TAB_ID1, c4d.BFH_SCALEFIT, tabtype=c4d.TAB_TABS) 
        self.GroupBegin(GROUP_ID1, c4d.BFH_SCALEFIT, 1, 3, title="taba") 
        
        self.GroupBegin(1, c4d.BFH_SCALEFIT, 3, 1, title="teil1")        
        self.AddStaticText(TEX_PATHS, c4d.BFH_LEFT, name="Texture Path: ")
        self.AddEditText(TEX_PATH, c4d.BFH_SCALEFIT)
        self.AddButton(BTN_OPEN, c4d.BFH_RIGHT, name="...")                
        self.GroupEnd() 
        
        self.GroupBegin(2, c4d.BFH_SCALEFIT, 1, 1,title="teil2") 
        self.AddStaticText(TEX_EXISTS, c4d.BFH_SCALEFIT, name="Path doesn't exist - please enter a valid path", borderstyle=5)
        self.SetDefaultColor(TEX_EXISTS, c4d.COLOR_TEXT, c4d.Vector(200, 0, 0))  
        self.GroupEnd() 
        
        
        self.GroupBegin(3, c4d.BFH_SCALEFIT, 1, 1,title="teil3")        
        self.AddButton(BTN_SET, c4d.BFH_SCALEFIT, name="Set texture Path")  
        self.Enable(BTN_SET, False)       
        self.GroupEnd()
          
        self.GroupEnd()         


        

        return True
   
    def InitValues(self):
        #initiate the gadgets with values
        return True
   
    def Command(self, id, msg):
        path = ""
        #handle user input
        if id==BTN_OPEN:
            self.SetString(TEX_PATH,c4d.storage.LoadDialog(title="Select texture folder...", flags=c4d.FILESELECT_DIRECTORY))
            path = self.GetString(TEX_PATH)
            checkPath(path,self)
        elif id==BTN_SET:
            replaceTexturepath(path)
            self.Close()
        elif id==TEX_PATH:
            path = self.GetString(TEX_PATH)
            checkPath(path,self)        
   
        return True


class TexPath(plugins.CommandData):
    
    
    
    dialog = None

    def Execute(self,doc):
        x= (c4d.gui.GeGetScreenDimensions(1,1,False)['sx2'] / 2) - DW/2
        y= (c4d.gui.GeGetScreenDimensions(1,1,False)['sy2'] / 2) - DH/2      
        if self.dialog is None:
            self.dialog = MainDialog()

        return self.dialog.Open(dlgtype = c4d.DLG_TYPE_ASYNC,pluginid = __plugin_id__,defaultw=DW,defaulth=DH,xpos=x,ypos=y)

    def RestoreLayout(self, sec_ref):
        if self.dialog is None:
            self.dialog = MainDialog()

        return self.dialog.Restore(pluginid = __plugin_id__, secret = sec_ref)
    
def main():
    dialog = MainDialog()
    x= (c4d.gui.GeGetScreenDimensions(1,1,False)['sx2'] / 2) - DW/2
    y= (c4d.gui.GeGetScreenDimensions(1,1,False)['sy2'] / 2) - DH/2   
    dialog.Open(dlgtype = c4d.DLG_TYPE_MODAL,pluginid = __plugin_id__,defaultw=DW,defaulth=DH,xpos=x,ypos=y)



if __name__ == "__main__":
    main()
    #plugins.RegisterCommandPlugin(id = __plugin_id__,str = __plugin_title__,info = 0,help = HELP_TEXT,dat = TexPath(),icon = icon)
