import c4d, os
from c4d import bitmaps
from c4d.modules import render
import shutil
import sys

############################################################
# Helpfunction to get the next object
############################################################
def GetNextObject(op):
    if op==None: return None
 
    if op.GetDown(): return op.GetDown()
 
    while not op.GetNext() and op.GetUp():
        op = op.GetUp()
 
    return op.GetNext() 


############################################################
# Optimize all Polygon Objects
############################################################
def optimize():
    obj = doc.GetFirstObject()
    if obj==None: return
 
    while obj:
        if obj.GetType() == c4d.Opolygon : c4d.CallCommand(14039) # Optimize         
        obj = GetNextObject(obj)         
    

############################################################
# Copy Textures to a Path
############################################################
def copyTextures(path):
    textures = doc.GetAllTextures()
    for t in textures:
        filename = os.path.basename(t[1]) 
        dirname = os.path.dirname(t[1])
        shutil.copy2(t[1], path+"\\"+filename) 
    
    
############################################################
# recursive function where we do stuff to the shaders
############################################################
def shadertree(shader,path):
    # Loop through the BaseList
    while(shader):         

        # This is where you do stuff
        # If it's a bitmap, we'll look at the filename

        if shader.GetType() == c4d.Xbitmap:
                   
            filename = shader[c4d.BITMAPSHADER_FILENAME]  
                  
            
            # for instance we can set the filename to just the file part
            filename = os.path.basename(filename)
            shader[c4d.BITMAPSHADER_FILENAME] = path+"\\"+filename
         
        # Check for child shaders & recurse
        if shader.GetDown(): shadertree(shader.GetDown())
        # Get the Next Shader
        shader = shader.GetNext() 
         
############################################################
# replaceTexturepath
############################################################
def replaceTexturepath(path):
    # Get the first material
    mat = doc.GetFirstMaterial()
    # Loop through materials
    while(mat):       
        # Get the first shader
        # Note - this is a 4D list - you've gotta GetDown
        shd = mat.GetFirstShader()
        # Use our recursive function to parse the shader tree
        shadertree(shd,path)
        # Get the Next material
        mat = mat.GetNext()        
 
if __name__=='__main__':
    c4d.CallCommand(13957) # Konsole löschen
    optimize()
    #replaceTexturepath("D:\Testordner")
